/*
* Copyright (c) 2002 Sshtools.com All rights reserved.
*
* Redistribution and use in source and binary forms, with or without modification,
* are permitted provided that the following conditions are met:
*
* Redistributions of source code must retain the above copyright notice, this list
* of conditions and the following disclaimer.
*
* Redistributions in binary form must reproduce the above copyright notice, this
* list of conditions and the following disclaimer in the documentation and/or other
* materials provided with the distribution.
*
* Neither the name of the Sshtools.com nor the names of its contributors may be
* used to endorse or promote products derived from this software without specific
* prior written permission.
*
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
* ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
* IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
* INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
* BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
* DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
* LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
* OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
* OF THE POSSIBILITY OF SUCH DAMAGE.
*
*/

package com.sshtools.j2ssh.authentication;

import java.util.*;
import com.sshtools.j2ssh.transport.InvalidStateException;

/**
 *  <p>
 *
 *  Holds the state of the authentication protocol.</p>
 *
 *@author     Lee David Painter (<A HREF="mailto:lee@sshtools.com">
 *      lee@sshtools.com</A> )
 *@version    1.0
 */

public class AuthenticationProtocolState {

    /**
     *  Description of the Field
     */
    public final static int INITIALIZING = 0;
    /**
     *  Description of the Field
     */
    public final static int READY = 1;
    /**
     *  Description of the Field
     */
    public final static int FAILED = 2;
    /**
     *  Description of the Field
     */
    public final static int PARTIAL = 3;
    /**
     *  Description of the Field
     */
    public final static int COMPLETE = 4;

    private int state = INITIALIZING;


    /**
     *  <p>
     *
     *  Constructor for the state object.</p>
     */
    public AuthenticationProtocolState() { }


    /**
     *  <p>
     *
     *  Gets the current state.</p>
     *
     *@return
     */
    public synchronized int getState() {
        return state;
    }


    /**
     *  <p>
     *
     *  Update to the state supplied.</p>
     *
     *@param  state                      The new state
     *@exception  InvalidStateException  Description of the Exception
     */
    public synchronized void updateState(int state)
             throws InvalidStateException {

        if (state != INITIALIZING && state != READY && state != FAILED
                && state != PARTIAL && state != COMPLETE) {
            throw new InvalidStateException("Invalid AuthenticationProtocolState");
        }

        this.state = state;

        notifyAll();

    }


    /**
     *  <p>
     *
     *  Synchronized method to wait for a state update.</p>
     *
     *@param  waitForState  Description of the Parameter
     *@return               The new state
     */
    public synchronized int waitForState(int waitForState) {

        while (state != waitForState) {
            try {
                wait();
            } catch (InterruptedException ie) {

            }
        }
        return state;
    }


    /**
     *  Description of the Method
     *
     *@return    Description of the Return Value
     */
    public synchronized int waitForStateUpdate() {

        try {
            wait();
        } catch (InterruptedException ie) {

        }

        return state;
    }

}
