/*
* Copyright (c) 2002 Sshtools.com All rights reserved.
*
* Redistribution and use in source and binary forms, with or without modification,
* are permitted provided that the following conditions are met:
*
* Redistributions of source code must retain the above copyright notice, this list
* of conditions and the following disclaimer.
*
* Redistributions in binary form must reproduce the above copyright notice, this
* list of conditions and the following disclaimer in the documentation and/or other
* materials provided with the distribution.
*
* Neither the name of the Sshtools.com nor the names of its contributors may be
* used to endorse or promote products derived from this software without specific
* prior written permission.
*
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
* ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
* IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
* INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
* BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
* DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
* LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
* OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
* OF THE POSSIBILITY OF SUCH DAMAGE.
*
*/

package com.sshtools.j2ssh.authentication;

import java.awt.*;
import javax.swing.*;
import com.borland.jbcl.layout.*;
import java.awt.event.*;
import com.sshtools.util.ImagePanel;

/**
 *  <p>
 *
 *  Implements the password login screen for the PasswrodAuthentication object
 *  </p>
 *
 *@author     Lee David Painter (<A HREF="mailto:lee@sshtools.com">
 *      lee@sshtools.com</A> )
 *@version    1.0
 */

public class PasswordAuthenticationDialog extends JDialog {

    /**
     *  Dialog components
     */
    XYLayout xYLayoutMain = new XYLayout();
    JPanel jPanelDetails = new JPanel();
    XYLayout xYLayoutDetails = new XYLayout();
    JLabel jLabelPassword = new JLabel();
    JPasswordField jPasswordField = new JPasswordField();
    JButton jButtonOK = new JButton();
    JTextField jTextUsername = new JTextField();
    JLabel jLabelUsername = new JLabel();
    ImagePanel icon = new ImagePanel("/com/sshtools/j2ssh/authentication/keys.gif");

    /**
     *  <p>
     *
     *  Flag to indicate whether the user cancelled the dialog or not.</p>
     */
    boolean userCancelled = false;
  JButton jButtonCancel = new JButton();


    /**
     *  <p>
     *
     *  Constructs the dialog.</p>
     *
     *@param  frame  The parent frame
     */
    public PasswordAuthenticationDialog(Frame frame) {
        super(frame, "Password Authentication", true);

        this.setLocationRelativeTo(frame);

        try {
            jbInit();
            pack();
        } catch (Exception ex) {
            ex.printStackTrace();
        }
    }


    /**
     *  Description of the Method
     *
     *@exception  Exception  Description of the Exception
     */
    void jbInit() throws Exception {


        this.getContentPane().setLayout(xYLayoutMain);
        jPanelDetails.setBorder(BorderFactory.createEtchedBorder());
        jPanelDetails.setLayout(xYLayoutDetails);
        jLabelPassword.setText("Password");
        xYLayoutMain.setWidth(289);
        xYLayoutMain.setHeight(138);
        jButtonOK.setText("OK");
        jButtonOK.addActionListener(
            new java.awt.event.ActionListener() {
                public void actionPerformed(ActionEvent e) {
                    jButtonOK_actionPerformed(e);
                }
            });

        // Add a window listener to see when the window closes without
        // selecting OK
        addWindowListener(
            new WindowAdapter() {
                public void windowClosing(WindowEvent evt) {
                    userCancelled = true;
                }
            });


        jLabelUsername.setText("Username");
        this.setModal(true);
        this.setResizable(false);
        jButtonCancel.addActionListener(new java.awt.event.ActionListener() {
                public void actionPerformed(ActionEvent e) {
                    jButtonCancel_actionPerformed(e);
                }
            });
    jButtonCancel.setText("Cancel");
    jPanelDetails.add(jTextUsername,  new XYConstraints(53, 22, 216, 19));
        jPanelDetails.add(jLabelPassword, new XYConstraints(54, 47, 284, 15));
        jPanelDetails.add(jPasswordField, new XYConstraints(53, 65, 216, 20));
        jPanelDetails.add(jLabelUsername, new XYConstraints(54, 3, 147, 20));
        jPanelDetails.add(icon,   new XYConstraints(8, 10, 32, 32));
    this.getContentPane().add(jButtonCancel, new XYConstraints(119, 107, 78, 25));
        this.getContentPane().add(jButtonOK,    new XYConstraints(205, 107, 78, 25));
        this.getContentPane().add(jPanelDetails,  new XYConstraints(5, 6, 278, 96));

        jPasswordField.requestFocus();
    }


    /**
     *  <p>
     *
     *  Display the dialog and return true to indicate that the authentication
     *  is ready to be performed.</p>
     *
     *@param  username  The username
     *@return           Is the authentication ready?
     */
    public boolean showPromptForPassword(String username) {

        jTextUsername.setText(username);

        showCentered();

        return !userCancelled;

    }


    /**
     *  <p>
     *
     *  Gets the password entered by the user.</p>
     *
     *@return    The users password
     */
    public String getPassword() {
        return String.valueOf(jPasswordField.getPassword());
    }


    /**
     *  <p>
     *
     *  Gets the username supplied by the user.</p>
     *
     *@return    The username
     */
    public String getUsername() {
        return jTextUsername.getText();
    }


    /**
     *  <p>
     *
     *  Handles the OK button event.</p>
     *
     *@param  e  The action
     */
    void jButtonOK_actionPerformed(ActionEvent e) {

        if (jTextUsername.getText().trim().equals("")) {
            JOptionPane.showMessageDialog(this, "You must enter a username!", "Password Authentication", JOptionPane.OK_OPTION);
            return;
        }

        hide();
    }

   /**
    * Shows the dialog in the center of the parent frame
    */
   public void showCentered() {
    Frame parent = (Frame)getParent();
    Dimension dim = parent.getSize();
    Point     loc = parent.getLocationOnScreen();

    Dimension size = getSize();

    loc.x += (dim.width  - size.width)/2;
    loc.y += (dim.height - size.height)/2;

    if (loc.x < 0) loc.x = 0;
    if (loc.y < 0) loc.y = 0;

    Dimension screen = getToolkit().getScreenSize();

    if (size.width  > screen.width)
      size.width  = screen.width;
    if (size.height > screen.height)
      size.height = screen.height;

    if (loc.x + size.width > screen.width)
      loc.x = screen.width - size.width;

    if (loc.y + size.height > screen.height)
      loc.y = screen.height - size.height;

    setBounds(loc.x, loc.y, size.width, size.height);
    show();
  }

  /**
   * The cancel action
   * @param e
   */
  void jButtonCancel_actionPerformed(ActionEvent e) {
      userCancelled = true;
      hide();
  }

}
