/*
* Copyright (c) 2002 Sshtools.com All rights reserved.
*
* Redistribution and use in source and binary forms, with or without modification,
* are permitted provided that the following conditions are met:
*
* Redistributions of source code must retain the above copyright notice, this list
* of conditions and the following disclaimer.
*
* Redistributions in binary form must reproduce the above copyright notice, this
* list of conditions and the following disclaimer in the documentation and/or other
* materials provided with the distribution.
*
* Neither the name of the Sshtools.com nor the names of its contributors may be
* used to endorse or promote products derived from this software without specific
* prior written permission.
*
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
* ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
* IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
* INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
* BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
* DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
* LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
* OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
* OF THE POSSIBILITY OF SUCH DAMAGE.
*
*/

package com.sshtools.j2ssh.authentication;
import java.awt.Frame;
import com.sshtools.j2ssh.authentication.AuthenticationProtocolException;
import com.sshtools.j2ssh.transport.TransportProtocol;
import com.sshtools.j2ssh.transport.TransportProtocolException;
/**
 *  <p>
 *
 *  Interface for an SSH Authentication</p>
 *
 *@author     Lee David Painter (<A HREF="mailto:lee@sshtools.com">
 *      lee@sshtools.com</A> )
 *@version    1.0
 */

public interface SshAuthentication {

    /**
     *  <p>
     *
     *  The main authentication method; an implementation should authenticate by
     *  using the messages detailed in the method specification. The
     *  authentication protocol handles the success or failure.</p>
     *
     *@param  transport                            The transport protocol to
     *      send through
     *@param  serviceToStart                       The Service to start after
     *      authentication
     *@exception  AuthenticationProtocolException
     *@exception  TransportProtocolException       Description of the Exception
     */
    public void authenticate(TransportProtocol transport, String serviceToStart)
             throws TransportProtocolException,
            AuthenticationProtocolException;


    /**
     *  <p>
     *
     *  An implementation should display a modal dialog so that the user can
     *  enter method specific information; this is only called on GUI
     *  implementations.</p>
     *
     *@param  parent  The parent frame
     *@return         Returns true if authentication is ready
     */
    public boolean showAuthenticationDialog(Frame parent);


    /**
     *  <p>
     *
     *  Gets the authentication method name.</p>
     *
     *@return    The method name
     */
    public String getMethodName();


    /**
     *  <p>
     *
     *  Sets the username for the authentication; this is called by the
     *  framework to provide the authentication method with the username from
     *  the connection properties. It is possible for the user to specify a
     *  different username so an implementation should use this to default only.
     *  </p>
     *
     *@param  username  The user's name
     */
    public void setUsername(String username);

}
