/*
* Copyright (c) 2002 Sshtools.com All rights reserved.
*
* Redistribution and use in source and binary forms, with or without modification,
* are permitted provided that the following conditions are met:
*
* Redistributions of source code must retain the above copyright notice, this list
* of conditions and the following disclaimer.
*
* Redistributions in binary form must reproduce the above copyright notice, this
* list of conditions and the following disclaimer in the documentation and/or other
* materials provided with the distribution.
*
* Neither the name of the Sshtools.com nor the names of its contributors may be
* used to endorse or promote products derived from this software without specific
* prior written permission.
*
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
* ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
* IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
* INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
* BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
* DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
* LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
* OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
* OF THE POSSIBILITY OF SUCH DAMAGE.
*
*/

package com.sshtools.j2ssh.authentication;

import java.io.*;
import com.sshtools.j2ssh.transport.InvalidMessageException;
import com.sshtools.j2ssh.transport.SshMessage;
import com.sshtools.util.ByteArrayWriter;
import com.sshtools.util.ByteArrayReader;
/**
 *  <p>
 *
 *  This class implements the SSH_MSG_USERAUTH_BANNER message</p>
 *
 *@author     Lee David Painter (<A HREF="mailto:lee@sshtools.com">
 *      lee@sshtools.com</A> )
 *@version    1.00
 */

public class SshMsgUserAuthBanner extends SshMessage {

    private String banner;
    private String languageTag;

    /**
     *  Description of the Field
     */
    public final static int SSH_MSG_USERAUTH_BANNER = 53;


    /**
     *  <p>
     *
     *  Constructor for the message</p>
     */
    public SshMsgUserAuthBanner() {
        super(SSH_MSG_USERAUTH_BANNER);
    }


    /**
     *  <p>
     *
     *  Gets the message name for debugging.</p>
     *
     *@return    The message name
     */
    public String getMessageName() {
        return "SSH_MSG_USERAUTH_BANNER";
    }


    /**
     *  <p>
     *
     *  Constructs the message from data received.</p>
     *
     *@param  bar                                                       The byte
     *      array containing the message
     *@exception  com.sshtools.j2ssh.transport.InvalidMessageException
     *      Description of the Exception
     *@throws  InvalidMessageException
     */
    protected void constructMessage(ByteArrayReader bar) throws com.sshtools.j2ssh.transport.InvalidMessageException {

        try {

            banner = bar.readString();
            languageTag = bar.readString();

        } catch (IOException ioe) {
            throw new InvalidMessageException("Error reading the message data");
        }
    }


    /**
     *  <p>
     *
     *  Constructs a byye array containing the message data.</p>
     *
     *@param  baw                                                       The byte
     *      array being written to.
     *@exception  com.sshtools.j2ssh.transport.InvalidMessageException
     *      Description of the Exception
     *@throws  InvalidMessageException
     */
    protected void constructByteArray(ByteArrayWriter baw) throws com.sshtools.j2ssh.transport.InvalidMessageException {

        try {

            baw.writeString(banner);
            baw.writeString(languageTag);

        } catch (IOException ioe) {
            throw new InvalidMessageException("Error writing the message data");
        }
    }


    /**
     *  <p>
     *
     *  Gets the banner text.</p>
     *
     *@return
     */
    public String getBanner() {
        return banner;
    }


    /**
     *  <p>
     *
     *  Gets the language tag.</p>
     *
     *@return
     */
    public String getLanguageTag() {
        return languageTag;
    }

}
