/*
* Copyright (c) 2002 Sshtools.com All rights reserved.
*
* Redistribution and use in source and binary forms, with or without modification,
* are permitted provided that the following conditions are met:
*
* Redistributions of source code must retain the above copyright notice, this list
* of conditions and the following disclaimer.
*
* Redistributions in binary form must reproduce the above copyright notice, this
* list of conditions and the following disclaimer in the documentation and/or other
* materials provided with the distribution.
*
* Neither the name of the Sshtools.com nor the names of its contributors may be
* used to endorse or promote products derived from this software without specific
* prior written permission.
*
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
* ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
* IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
* INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
* BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
* DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
* LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
* OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
* OF THE POSSIBILITY OF SUCH DAMAGE.
*
*/

package com.sshtools.j2ssh.authentication;
import java.io.*;
import java.util.*;
import com.sshtools.j2ssh.transport.InvalidMessageException;
import com.sshtools.util.ByteArrayWriter;
import com.sshtools.util.ByteArrayReader;

/**
 *  <p>
 *
 *  Implements the SSH_MSG_USERAUTH_REQUEST for the password authentication
 *  method</p>
 *
 *@author     Lee David Painter (<A HREF="mailto:lee@sshtools.com">
 *      lee@sshtools.com</A> )
 *@version    1.0
 */

public class SshMsgUserAuthPwdRequest extends SshMsgUserAuthRequest {

    private String password;


    /**
     *  Constructors the message
     *
     *@param  username     The users name
     *@param  password     The users password
     *@param  serviceName  The service name to start
     */
    public SshMsgUserAuthPwdRequest(String username, String password, String serviceName) {
        super(username, serviceName, "password");

        this.password = password;

    }


    /**
     *  Constructs the message
     *
     *@exception  InvalidMessageException
     */
    public SshMsgUserAuthPwdRequest() throws InvalidMessageException {
        super();

    }


    /**
     *  <p>
     *
     *  Gets the password.</p>
     *
     *@return    The password
     */
    public String getPassword() {

        return password;
    }


    /**
     *  <p>
     *
     *  Constructs the message from a byte array.</p>
     *
     *@param  bar                          The byte array being read
     *@exception  InvalidMessageException
     */
    protected void constructMessage(ByteArrayReader bar) throws InvalidMessageException {

        try {
            super.constructMessage(bar);

            bar.read();

            password = bar.readString();

        } catch (IOException ioe) {
            throw new InvalidMessageException("Invalid message data");
        }
    }


    /**
     *  <p>
     *
     *  Constructs a byte array containing the message.</p>
     *
     *@param  baw                          The byte array being written
     *@exception  InvalidMessageException
     */
    protected void constructByteArray(ByteArrayWriter baw) throws InvalidMessageException {

        try {
            super.constructByteArray(baw);

            baw.write(0);

            baw.writeString(password);
        } catch (IOException ioe) {
            throw new InvalidMessageException("Invalid message data");
        }
    }

}
