/*
* Copyright (c) 2002 Sshtools.com All rights reserved.
*
* Redistribution and use in source and binary forms, with or without modification,
* are permitted provided that the following conditions are met:
*
* Redistributions of source code must retain the above copyright notice, this list
* of conditions and the following disclaimer.
*
* Redistributions in binary form must reproduce the above copyright notice, this
* list of conditions and the following disclaimer in the documentation and/or other
* materials provided with the distribution.
*
* Neither the name of the Sshtools.com nor the names of its contributors may be
* used to endorse or promote products derived from this software without specific
* prior written permission.
*
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
* ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
* IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
* INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
* BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
* DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
* LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
* OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
* OF THE POSSIBILITY OF SUCH DAMAGE.
*
*/

package com.sshtools.j2ssh.connection;

import java.io.IOException;
import com.sshtools.j2ssh.transport.InvalidMessageException;
import com.sshtools.j2ssh.transport.SshMessage;
import com.sshtools.util.ByteArrayWriter;
import com.sshtools.util.ByteArrayReader;

/**
 *  <p>
 *
 *  Implements the SSH_MSG_CHANNEL_EOF message.</p>
 *
 *@author     Lee David Painter (<A HREF="mailto:lee@sshtools.com">
 *      lee@sshtools.com</A> )
 *@version    1.0
 */

public class SshMsgChannelEOF extends SshMessage {

    /**
     *  The message id
     */
    protected final static int SSH_MSG_CHANNEL_EOF = 96;

    private long recipientChannel;


    /**
     *  Constructor for the SshMsgChannelEOF object
     *
     *@param  recipientChannel  The recipients channel id
     */
    public SshMsgChannelEOF(long recipientChannel) {
        super(SSH_MSG_CHANNEL_EOF);
        this.recipientChannel = recipientChannel;
    }


    /**
     *  Constructor for the SshMsgChannelEOF object
     */
    public SshMsgChannelEOF() {
        super(SSH_MSG_CHANNEL_EOF);
    }


    /**
     *  Gets the recipient channel id
     *
     *@return    The recipients channel id
     */
    public long getRecipientChannel() {
        return recipientChannel;
    }


    /**
     *  Gets the messageName attribute of the SshMsgChannelEOF object
     *
     *@return    The messageName value
     */
    public String getMessageName() {
        return "SSH_MSG_CHANNEL_EOF";
    }


    /**
     *  Description of the Method
     *
     *@param  bar                          Description of the Parameter
     *@exception  InvalidMessageException  Description of the Exception
     */
    protected void constructMessage(ByteArrayReader bar) throws InvalidMessageException {

        try {

            recipientChannel = bar.readInt();

        } catch (IOException ioe) {
            throw new InvalidMessageException("Invalid message data");
        }
    }


    /**
     *  Description of the Method
     *
     *@param  baw                          Description of the Parameter
     *@exception  InvalidMessageException  Description of the Exception
     */
    protected void constructByteArray(ByteArrayWriter baw) throws InvalidMessageException {

        try {

            baw.writeInt(recipientChannel);

        } catch (IOException ioe) {
            throw new InvalidMessageException("Invalid message data");
        }
    }
}
