/*
* Copyright (c) 2002 Sshtools.com All rights reserved.
*
* Redistribution and use in source and binary forms, with or without modification,
* are permitted provided that the following conditions are met:
*
* Redistributions of source code must retain the above copyright notice, this list
* of conditions and the following disclaimer.
*
* Redistributions in binary form must reproduce the above copyright notice, this
* list of conditions and the following disclaimer in the documentation and/or other
* materials provided with the distribution.
*
* Neither the name of the Sshtools.com nor the names of its contributors may be
* used to endorse or promote products derived from this software without specific
* prior written permission.
*
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
* ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
* IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
* INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
* BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
* DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
* LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
* OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
* OF THE POSSIBILITY OF SUCH DAMAGE.
*
*/

package com.sshtools.j2ssh.transport;
import com.sshtools.j2ssh.SshException;

/**
 *  <p>
 *
 *  The transport layer throws this exception when an attempt is made to
 *  unregister a message that has not been registered.</p> <p>
 *
 *  CAUSES: <br>
 *  Did you register it in the first place!<br>
 *  Was it yours to unregister!</p>
 *
 *@author     Lee David Painter (<A HREF="mailto:lee@sshtools.com">
 *      lee@sshtools.com</A> )
 *@created    31 August 2002
 *@version    1.0
 */

public class MessageNotRegisteredException extends SshException {

    /**
     *  <p>
     *
     *  Constructs the exception.</p>
     *
     *@param  messageId  The message id of the unregistered message
     */
    public MessageNotRegisteredException(Integer messageId) {
        super("Message Id " + messageId.toString() + " is not currently registered");
    }


    /**
     *  <p>
     *
     *  Constructs the exception.</p>
     *
     *@param  messageId  The message id of the unregistered message.
     *@param  store      The message store object that tried to unregister the
     *      message.
     */
    public MessageNotRegisteredException(Integer messageId, SshMessageStore store) {
        super("Message Id " + messageId.toString() + " is not registered to the message store specified");
    }
}
