/*
* Copyright (c) 2002 Sshtools.com All rights reserved.
*
* Redistribution and use in source and binary forms, with or without modification,
* are permitted provided that the following conditions are met:
*
* Redistributions of source code must retain the above copyright notice, this list
* of conditions and the following disclaimer.
*
* Redistributions in binary form must reproduce the above copyright notice, this
* list of conditions and the following disclaimer in the documentation and/or other
* materials provided with the distribution.
*
* Neither the name of the Sshtools.com nor the names of its contributors may be
* used to endorse or promote products derived from this software without specific
* prior written permission.
*
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
* ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
* IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
* INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
* BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
* DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
* LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
* OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
* OF THE POSSIBILITY OF SUCH DAMAGE.
*
*/

package com.sshtools.j2ssh.transport;

import java.io.IOException;
import com.sshtools.util.ByteArrayWriter;
import com.sshtools.util.ByteArrayReader;
/**
 *  <p>
 *
 *  Implements the new keys message, sent after completioin of key exchange.</p>
 *  <p>
 *
 *  Key exchange ends by each side sending an SSH_MSG_NEWKEYS message. This
 *  message is sent with the old keys and algorithms. All messages sent after
 *  this message MUST use the new keys and algorithms.</p> <p>
 *
 *  When this message is received, the new keys and algorithms MUST be taken
 *  into use for receiving.</p> <p>
 *
 *  This message is the only valid message after key exchange, in addition to
 *  SSH_MSG_DEBUG, SSH_MSG_DISCONNECT and SSH_MSG_IGNORE messages. The purpose
 *  of this message is to ensure that a party is able to respond with a
 *  disconnect message that the other party can understand if something goes
 *  wrong with the key exchange. Implementations MUST NOT accept any other
 *  messages after key exchange before receiving SSH_MSG_NEWKEYS.</p> <p>
 *
 *  <b>byte SSH_MSG_NEWKEYS</p> </b>
 *
 *@author     Lee David Painter (<A HREF="mailto:lee@sshtools.com">
 *      lee@sshtools.com</A> )
 *@created    31 August 2002
 *@version    1.0
 */

class SshMsgNewKeys extends SshMessage {

    /**
     *  The message id of the message
     */
    protected final static int SSH_MSG_NEWKEYS = 21;


    /**
     *  Constucts the message for sending
     */
    public SshMsgNewKeys() {
        super(SSH_MSG_NEWKEYS);
    }


    /**
     *  Gets the messageName attribute of the SshMsgNewKeys object
     *
     *@return    The messageName value
     */
    public String getMessageName() {
        return "SSH_MSG_NEWKEYS";
    }


    /**
     *  <p>
     *
     *  Abstract method implementation to construct the message from data
     *  received.</p>
     *
     *@param  bar                          The data received.
     *@exception  InvalidMessageException  Thrown when the data cannot be read.
     */
    protected void constructMessage(ByteArrayReader bar) throws InvalidMessageException { }


    /**
     *  <p>
     *
     *  Abstrct method implementation to constrcut a byte array.</p>
     *
     *@param  baw                          The byte array being written to.
     *@exception  InvalidMessageException  Thrown when the data cannot be
     *      written.
     */
    protected void constructByteArray(ByteArrayWriter baw) throws InvalidMessageException { }
}
