/*
* Copyright (c) 2002 Sshtools.com All rights reserved.
*
* Redistribution and use in source and binary forms, with or without modification,
* are permitted provided that the following conditions are met:
*
* Redistributions of source code must retain the above copyright notice, this list
* of conditions and the following disclaimer.
*
* Redistributions in binary form must reproduce the above copyright notice, this
* list of conditions and the following disclaimer in the documentation and/or other
* materials provided with the distribution.
*
* Neither the name of the Sshtools.com nor the names of its contributors may be
* used to endorse or promote products derived from this software without specific
* prior written permission.
*
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
* ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
* IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
* INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
* BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
* DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
* LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
* OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
* OF THE POSSIBILITY OF SUCH DAMAGE.
*
*/

package com.sshtools.j2ssh.transport;

/**
 *  <p>
 *
 *  The transport protocol can only send specific transport messages whilst in
 *  key exchange. This can happen at any time if the remote or local side send
 *  another SSH_MSG_KEX_INIT. This state object allows the transport layer to
 *  maintain its state so that it can queue messages received from attached
 *  services whilst completing the key exchange.</p>
 *
 *@author     Lee David Painter (<A HREF="mailto:lee@sshtools.com">
 *      lee@sshtools.com</A> )
 *@created    31 August 2002
 *@version    1.0
 */

public class TransportProtocolState {

    private boolean isReady = false;


    /**
     *  The Constructor
     */
    public TransportProtocolState() { }


    /**
     *  Returns whether the transport protocol is ready
     *
     *@return
     */
    public synchronized boolean isReady() {
        return isReady;
    }


    /**
     *  Waits for a ready state
     */
    public synchronized void waitForReadyState() {

        while (isReady == false) {

            try {
                wait();
            } catch (InterruptedException e) {

            }
        }

    }


    /**
     *  Sets the state as ready
     *
     *@param  isReady
     */
    public synchronized void setReadyState(boolean isReady) {

        this.isReady = isReady;

        notifyAll();

    }

}
