/*
* Copyright (c) 2002 Sshtools.com All rights reserved.
*
* Redistribution and use in source and binary forms, with or without modification,
* are permitted provided that the following conditions are met:
*
* Redistributions of source code must retain the above copyright notice, this list
* of conditions and the following disclaimer.
*
* Redistributions in binary form must reproduce the above copyright notice, this
* list of conditions and the following disclaimer in the documentation and/or other
* materials provided with the distribution.
*
* Neither the name of the Sshtools.com nor the names of its contributors may be
* used to endorse or promote products derived from this software without specific
* prior written permission.
*
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
* ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
* IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
* INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
* BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
* DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
* LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
* OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
* OF THE POSSIBILITY OF SUCH DAMAGE.
*
*/

package com.sshtools.j2ssh.transport.publickey;


/**
 *  <p>
 *
 *  Defines a public key mechanism for use within the SSH API</p>
 *
 *@author     Lee David Painter (<A HREF="mailto:lee@sshtools.com">
 *      lee@sshtools.com</A> )
 *@created    31 August 2002
 *@version    1.0
 */

public interface SshPublicKey {

    /**
     *  Called by the framework to initialize the key
     *
     *@param  hostkey                   The host key data
     *@throws  InvalidHostKeyException  Throw if the host key data is invalid
     */
    public void init(byte[] hostkey) throws InvalidHostKeyException;


    /**
     *  Implement this to return a formatted key string
     *
     *@return    The formatted key
     */
    public String getFormattedKey();


    /**
     *  Implement this method to return the keys fingerprint
     *
     *@return    The fingerprint value
     */
    public String getFingerprint();


    /**
     *  Implement this method to verify the signature
     *
     *@param  signature                             The signature to verify
     *@param  exchangeHash                          The exchange hash output of
     *      key exchange
     *@return                                       The success of the
     *      verification
     *@exception  InvalidHostKeySignatureException  Throw if the signature is in
     *      an invalid format (not for a verification failure)
     */
    public boolean verifySignature(byte[] signature, byte[] exchangeHash)
             throws InvalidHostKeySignatureException;
}
