/*
* Copyright (c) 2002 Sshtools.com All rights reserved.
*
* Redistribution and use in source and binary forms, with or without modification,
* are permitted provided that the following conditions are met:
*
* Redistributions of source code must retain the above copyright notice, this list
* of conditions and the following disclaimer.
*
* Redistributions in binary form must reproduce the above copyright notice, this
* list of conditions and the following disclaimer in the documentation and/or other
* materials provided with the distribution.
*
* Neither the name of the Sshtools.com nor the names of its contributors may be
* used to endorse or promote products derived from this software without specific
* prior written permission.
*
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
* ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
* IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
* INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
* BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
* DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
* LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
* OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
* OF THE POSSIBILITY OF SUCH DAMAGE.
*
*/

package com.sshtools.sshterm;

import java.awt.*;
import javax.swing.*;
import com.borland.jbcl.layout.*;
import java.util.*;
import java.awt.event.*;
import javax.swing.border.*;

/**
 *  <p>
 *
 *  Displays the list of availble authentication methods and allows the user to
 *  select on or more to authenticate with.</p>
 *
 *@author     Lee David Painter (<A HREF="mailto:lee@sshtools.com">
 *      lee@sshtools.com</A> )
 *@created    31 August 2002
 *@version    1.0
 */

class AuthenticationDialog extends CenterableDialog { //JDialog { //

    /**
     *  The dialog components
     */
    XYLayout xYLayoutMain = new XYLayout();
    JPanel jPanelAuths = new JPanel();
    XYLayout xYLayoutAuths = new XYLayout();
    JLabel jLabelDesc = new JLabel();
    JButton jButtonProceed = new JButton();
    BorderLayout borderLayout1 = new BorderLayout();
    Map panels = new HashMap();
    JList jListAuths = new JList();
    TitledBorder titledBorder1;


    /**
     *  The Constructor
     *
     *@param  frame  The parent frame
     */
    public AuthenticationDialog(Frame frame) {
        super(frame, "Select Authentication Method(s)", true);
        try {
            jbInit();
            pack();
        } catch (Exception ex) {
            ex.printStackTrace();
        }
    }


    /**
     *  Sets the authentication list to be displayed
     *
     *@param  methods  A list of methods
     */
    private void setMethodList(java.util.List methods) {

        jListAuths.setListData(methods.toArray());

    }


    /**
     *  Initiates the dialog
     *
     *@throws  Exception
     */
    void jbInit() throws Exception {
        titledBorder1 = new TitledBorder("");
        this.getContentPane().setLayout(xYLayoutMain);
        jPanelAuths.setLayout(xYLayoutAuths);

        xYLayoutMain.setWidth(330);
        xYLayoutMain.setHeight(184);

        jButtonProceed.setText("Proceed");
        jButtonProceed.addActionListener(
            new java.awt.event.ActionListener() {
                public void actionPerformed(ActionEvent e) {
                    jButtonProceed_actionPerformed(e);
                }
            });

        jListAuths.setBorder(BorderFactory.createEtchedBorder());
        jPanelAuths.add(jLabelDesc, new XYConstraints(7, 4, 304, 26));
        jPanelAuths.add(jListAuths, new XYConstraints(9, 33, 299, 100));

        this.getContentPane().add(jButtonProceed, new XYConstraints(240, 154, 84, 26));
        jPanelAuths.setBorder(BorderFactory.createEtchedBorder());

        jLabelDesc.setText("Please select an authentication method(s) to continue.");
        this.getContentPane().add(jPanelAuths, new XYConstraints(4, 4, 321, 145));
    }


    /**
     *  Call this method to show the dialog and return the list of selected
     *  methods
     *
     *@param  supported
     *@return
     */
    public java.util.List showAuthenticationMethods(java.util.List supported) {

        // Set the list
        this.setMethodList(supported);

        // Show the dialog
        this.showCentered();

        // Put the selected values into a new list and return
        java.util.List list = new ArrayList();

        Object[] methods = jListAuths.getSelectedValues();

        if (methods != null) {
            for (int i = 0; i < methods.length; i++) {
                list.add(methods[i]);
            }
        }

        return list;
    }


    /**
     *  Handles the proceed button event
     *
     *@param  e
     */
    void jButtonProceed_actionPerformed(ActionEvent e) {

        hide();
    }

}
