/*
* Copyright (c) 2002 Sshtools.com All rights reserved.
*
* Redistribution and use in source and binary forms, with or without modification,
* are permitted provided that the following conditions are met:
*
* Redistributions of source code must retain the above copyright notice, this list
* of conditions and the following disclaimer.
*
* Redistributions in binary form must reproduce the above copyright notice, this
* list of conditions and the following disclaimer in the documentation and/or other
* materials provided with the distribution.
*
* Neither the name of the Sshtools.com nor the names of its contributors may be
* used to endorse or promote products derived from this software without specific
* prior written permission.
*
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
* ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
* IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
* INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
* BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
* DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
* LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
* OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
* OF THE POSSIBILITY OF SUCH DAMAGE.
*
*/

package com.sshtools.sshterm;

import javax.swing.JDialog;
import java.awt.Frame;
import java.awt.Dimension;
import java.awt.Point;

/**
 *
 * <p>A utility class to be used as the base of all dialogs instead of JDialog.
 * The CenterableDialog provides a usefull means to center the dialog in the
 * parent frame.</p>
 *
 * @author     Lee David Painter (<A HREF="mailto:lee@sshtools.com">
 *      lee@sshtools.com</A> )
 *@created    31 August 2002
 *@version    1.0
 */
public class CenterableDialog extends JDialog {

  /**
   * Creates a new dialog
   * @param parent    The parent frame
   */
  public CenterableDialog(Frame parent) {
    super(parent);
  }

  /**
   * Create a new dialog
   * @param parent    The parent frame
   * @param title     The dialog's title
   *
   */
  public CenterableDialog(Frame parent,
                          String title) {
    super(parent, title);
  }

  /**
   * Creates a new dialog
   * @param parent    The parent frame
   * @param title     The dialog's title
   * @param modal     Specifies whether the dialog is modal
   */
  public CenterableDialog(Frame parent,
                          String title,
                          boolean modal) {
    super(parent, title, modal);

  }

  /**
   * Creates a new dialog
   * @param parent    The parent frame
   * @param modal     Specifies whether the dialog is modal
   */
  public CenterableDialog(Frame parent,
                          boolean modal) {
    super(parent, modal);
  }

  /**
   * Displays the dialog and positions it in the center of the parent frame
   */
  public void showCentered() {

    Frame parent = (Frame)getParent();
    Dimension dim = parent.getSize();
    Point     loc = parent.getLocationOnScreen();

    Dimension size = getSize();

    loc.x += (dim.width  - size.width)/2;
    loc.y += (dim.height - size.height)/2;

    if (loc.x < 0) loc.x = 0;
    if (loc.y < 0) loc.y = 0;

    Dimension screen = getToolkit().getScreenSize();

    if (size.width  > screen.width)
      size.width  = screen.width;
    if (size.height > screen.height)
      size.height = screen.height;

    if (loc.x + size.width > screen.width)
      loc.x = screen.width - size.width;

    if (loc.y + size.height > screen.height)
      loc.y = screen.height - size.height;

    setBounds(loc.x, loc.y, size.width, size.height);
    show();
  }
}