/*
* Copyright (c) 2002 Sshtools.com All rights reserved.
*
* Redistribution and use in source and binary forms, with or without modification,
* are permitted provided that the following conditions are met:
*
* Redistributions of source code must retain the above copyright notice, this list
* of conditions and the following disclaimer.
*
* Redistributions in binary form must reproduce the above copyright notice, this
* list of conditions and the following disclaimer in the documentation and/or other
* materials provided with the distribution.
*
* Neither the name of the Sshtools.com nor the names of its contributors may be
* used to endorse or promote products derived from this software without specific
* prior written permission.
*
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
* ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
* IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
* INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
* BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
* DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
* LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
* OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
* OF THE POSSIBILITY OF SUCH DAMAGE.
*
*/

package com.sshtools.sshterm;

import java.awt.*;
import javax.swing.*;
import com.borland.jbcl.layout.*;
import java.awt.event.*;
import com.sshtools.j2ssh.authentication.*;
import java.util.*;
import com.sshtools.j2ssh.transport.cipher.*;
import com.sshtools.j2ssh.transport.hmac.*;
import com.sshtools.j2ssh.transport.compression.*;
import com.sshtools.j2ssh.transport.publickey.*;
import com.sshtools.j2ssh.transport.kex.*;
import com.sshtools.j2ssh.configuration.*;
import com.sshtools.sshterm.emulation.TerminalEmulation;
import com.sshtools.util.ImagePanel;

/**
 *  <p>
 *
 *  The New Connection dialog for the SshTerminalFrame. This dialog allows the
 *  user to select connection properties</p>
 *
 *@author     Lee David Painter (<A HREF="mailto:lee@sshtools.com">
 *      lee@sshtools.com</A> )
 *@created    31 August 2002
 *@version    1.0
 */

class ConnectionDialog extends CenterableDialog { //JDialog { //

    /**
     *  The dialogs components!
     */
    JPanel jPanelHostDetail = new JPanel();
    XYLayout xYLayoutMain = new XYLayout();
    XYLayout xYLayoutHostDetail = new XYLayout();
    JLabel jLabelHostname = new JLabel();
    JTextField jTextHostname = new JTextField();
    JLabel jLabelPort = new JLabel();
    JTextField jTextPort = new JTextField();
    JLabel jLabelUsername = new JLabel();
    JTextField jTextUsername = new JTextField();
    JButton jButtonConnect = new JButton();
    JTabbedPane jTabOptions = new JTabbedPane();
    JPanel jPanelHost = new JPanel();
    JPanel jPanelPreferences = new JPanel();
    JPanel jPanelPreferencesDetail = new JPanel();
    JLabel jLabelCipherCS = new JLabel();
    XYLayout xYLayoutPreferencesDetail = new XYLayout();
    JComboBox jComboCipherCS = new JComboBox();
    JComboBox jComboCipherSC = new JComboBox();
    JLabel jLabelMacCS = new JLabel();
    JComboBox jComboMacCS = new JComboBox();
    JComboBox jComboMacSC = new JComboBox();
    JLabel jLabelCompCS = new JLabel();
    JComboBox jComboCompCS = new JComboBox();
    JComboBox jComboCompSC = new JComboBox();
    JList jListAuths = new JList();
    JLabel jLabelAuthMethods = new JLabel();
    JLabel jLabelKeyExchange = new JLabel();
    JComboBox jComboKex = new JComboBox();
    JLabel jLabelPublicKey = new JLabel();
    JComboBox jComboPK = new JComboBox();
    JLabel jLabelCipherSC = new JLabel();
    JLabel jLabelMacSC = new JLabel();
    JLabel jLabelCompSC = new JLabel();
    XYLayout xYLayoutPreferences = new XYLayout();
    java.util.List methods = new ArrayList();
    XYLayout xYLayoutHost = new XYLayout();
    ImagePanel icon = new ImagePanel("/com/sshtools/sshterm/connect.gif");
    boolean isCancelled = false;

    /**
     *  Flag to determine if the user selected any authenticaiton methods
     */
    boolean hasChosenAuth = false;
    final String SHOW_AVAILABLE = "<Show available methods>";
    final String DEFAULT = "<Default>";
    JLabel jLabel1 = new JLabel();
    JComboBox jComboTerm = new JComboBox();
    ImagePanel icon1 = new ImagePanel("/com/sshtools/sshterm/ssh.gif");
    ImagePanel icon2 = new ImagePanel("/com/sshtools/sshterm/authentication.gif");
    ImagePanel icon3 = new ImagePanel("/com/sshtools/sshterm/pref.gif");
  JLabel jLabel2 = new JLabel();
  JLabel jLabel3 = new JLabel();
  JPanel jPanel1 = new JPanel();
  JButton jButtonCancel = new JButton();



    /**
     *  Constructs the ConnectionDialog object
     *
     *@param  frame  The parent frame
     */
    public ConnectionDialog(Frame parent) {
        super(parent, "New Connection", true);

        try {
            jbInit();
            pack();
        } catch (Exception ex) {
            ex.printStackTrace();
        }
    }


    /**
     *  Initializes the dialogs components
     *
     *@exception  Exception
     */
    void jbInit() throws Exception {
        this.getContentPane().setLayout(xYLayoutMain);

        jPanelHostDetail.setLayout(xYLayoutHostDetail);
        jButtonConnect.setText("Connect");
        jButtonConnect.addActionListener(
            new java.awt.event.ActionListener() {
                public void actionPerformed(ActionEvent e) {
                    jButtonConnect_actionPerformed(e);
                }
            });

        jPanelHost.setLayout(xYLayoutHost);
        jPanelPreferences.setLayout(xYLayoutPreferences);
        jPanelPreferencesDetail.setBorder(BorderFactory.createEtchedBorder());
        jPanelPreferencesDetail.setLayout(xYLayoutPreferencesDetail);
        jLabelCipherCS.setToolTipText("");
        jLabelCipherCS.setText("Cipher");
        jLabelMacCS.setText("Mac");
        jLabelCompCS.setText("Compression");
        jListAuths.setBorder(BorderFactory.createLoweredBevelBorder());
        jLabelAuthMethods.setText("Authentication Methods");
        jLabelKeyExchange.setText("Key Exchange");
        jLabelPublicKey.setText("Public Key");
        jLabelCipherSC.setText("Cipher");
        jLabelMacSC.setText("Mac");
        jLabelCompSC.setText("Compression");
        jLabel1.setText("Terminal Type");
        jLabel2.setText("Client -> Server");
        jLabel3.setText("Server -> Client");
        jPanel1.setBorder(BorderFactory.createEtchedBorder());
        jButtonCancel.addActionListener(new java.awt.event.ActionListener() {
                    public void actionPerformed(ActionEvent e) {
                        jButtonCancel_actionPerformed(e);
                    }
                });
    jButtonCancel.setText("Cancel");
    jPanelHostDetail.add(jTextUsername,  new XYConstraints(53, 115, 230, 20));
    jPanelHostDetail.add(jLabelAuthMethods, new XYConstraints(55, 143, 162, 19));
    jPanelHostDetail.add(jListAuths, new XYConstraints(53, 163, 230, 79));
    jPanelHostDetail.add(jLabel1, new XYConstraints(55, 250, 146, 16));
    jPanelHostDetail.add(jComboTerm, new XYConstraints(55, 267, 171, -1));
    jPanelHostDetail.add(jLabelHostname, new XYConstraints(54, 3, 114, 18));
    jPanelHostDetail.add(jTextHostname, new XYConstraints(54, 23, 229, 20));
    jPanelHostDetail.add(jLabelPort, new XYConstraints(53, 46, 46, 18));
    jPanelHostDetail.add(jTextPort, new XYConstraints(55, 65, 47, -1));
    jPanelHostDetail.add(jLabelUsername, new XYConstraints(53, 92, 225, 24));
    jPanelHostDetail.add(icon,  new XYConstraints(8, 8, 33, 36));
    jPanelHostDetail.add(icon2,       new XYConstraints(8, 146, 33, 36));
    this.getContentPane().add(jButtonConnect,     new XYConstraints(272, 342, -1, 26));

    jPanelPreferencesDetail.add(icon1,     new XYConstraints(8, 8, 33, 36));
    jPanelPreferencesDetail.add(jLabelCipherCS, new XYConstraints(52, 142, 142, -1));
    jPanelPreferencesDetail.add(jComboCipherCS,   new XYConstraints(51, 160, 110, 20));
    jPanelPreferencesDetail.add(jLabelMacCS, new XYConstraints(53, 190, 145, 19));
    jPanelPreferencesDetail.add(jLabelCompCS, new XYConstraints(50, 237, 168, 19));
    jPanelPreferencesDetail.add(jComboCompCS,   new XYConstraints(49, 255, 111, -1));
    jPanelPreferencesDetail.add(jComboMacCS,  new XYConstraints(51, 208, 110, 20));
    jPanelPreferencesDetail.add(jComboPK,         new XYConstraints(54, 22, 230, 20));
    jPanelPreferencesDetail.add(jLabelPublicKey,    new XYConstraints(54, 4, 143, 18));
    jPanelPreferencesDetail.add(icon3,     new XYConstraints(6, 147, 41, 33));
    jPanelPreferencesDetail.add(jComboMacSC,  new XYConstraints(175, 207, 110, 20));
    jPanelPreferencesDetail.add(jComboCipherSC,   new XYConstraints(176, 159, 110, 20));
    jPanelPreferencesDetail.add(jComboCompSC,    new XYConstraints(176, 255, 108, -1));
    jPanelPreferencesDetail.add(jLabelCompSC, new XYConstraints(175, 238, 186, -1));
    jPanelPreferencesDetail.add(jLabelMacSC, new XYConstraints(175, 189, 134, 18));
    jPanelPreferencesDetail.add(jLabelCipherSC,  new XYConstraints(176, 139, 142, 19));
    jPanelPreferencesDetail.add(jLabel2,         new XYConstraints(53, 112, 108, 19));
    jPanelPreferencesDetail.add(jLabelKeyExchange,   new XYConstraints(55, 49, 143, 18));
    jPanelPreferencesDetail.add(jComboKex,   new XYConstraints(54, 68, 227, 20));
    jPanelPreferencesDetail.add(jPanel1, new XYConstraints(53, 132, 229, 4));
    jPanelPreferencesDetail.add(jLabel3,     new XYConstraints(177, 111, 98, 21));
    jTabOptions.add(jPanelHost, "Host");
    jPanelHost.add(jPanelHostDetail, new XYConstraints(5, 5, 337, 298));
    jTabOptions.add(jPanelPreferences, "Preferences");
    jPanelPreferences.add(jPanelPreferencesDetail, new XYConstraints(5, 5, 338, 298));
    this.getContentPane().add(jButtonCancel, new XYConstraints(183, 342, 81, 26));
    this.getContentPane().add(jTabOptions,    new XYConstraints(5, 0, 350, 335));
        this.setModal(true);
        this.setResizable(false);
        addAuthenticationMethods();
        jPanelHostDetail.setBorder(BorderFactory.createEtchedBorder());
        jLabelHostname.setText("Hostname");
        jLabelPort.setText("Port");
        jTextPort.setText("22");
        jLabelUsername.setText("Username");
        xYLayoutMain.setWidth(360);
        xYLayoutMain.setHeight(375);

        loadList(SshCipherFactory.getSupportedCiphers(), jComboCipherCS, true);
        loadList(SshCipherFactory.getSupportedCiphers(), jComboCipherSC, true);
        loadList(SshHmacFactory.getSupportedMacs(), jComboMacCS, true);
        loadList(SshHmacFactory.getSupportedMacs(), jComboMacSC, true);
        loadList(SshCompressionFactory.getSupportedCompression(), jComboCompCS, true);
        loadList(SshCompressionFactory.getSupportedCompression(), jComboCompSC, true);
        loadList(SshKeyExchangeFactory.getSupportedKeyExchanges(), jComboKex, true);
        loadList(SshPublicKeyFactory.getSupportedPublicKeys(), jComboPK, true);

        loadList(TerminalEmulation.getSupportedEmulations(), jComboTerm, false);
        jComboTerm.setSelectedItem(TerminalEmulation.VT100);
    }



    /**
     *  Shows the connection dialog and returns the connection properties
     *  selected.
     *
     *@return    The connection properties
     */
    public SshConnectionProperties showConnectionDialog() {

        // Show the dialog
        this.showCentered();

        if(isCancelled)
          return null;

        // Create a new properties object
        SshConnectionProperties ssh = new SshConnectionProperties();

        // Set the host details
        ssh.setHost(jTextHostname.getText());
        ssh.setPort(Integer.valueOf(jTextPort.getText()).intValue());
        ssh.setUsername(jTextUsername.getText());
        ssh.setTerminalType((String) jComboTerm.getSelectedItem());
        // Setup the authentications selected
        if (hasChosenAuth) {

            Iterator it = methods.iterator();

            while (it.hasNext()) {
                ssh.addAuthenticationMethod((String) it.next());
            }
        }

        // Get the algorithm preferences
        if (!jComboCipherCS.getSelectedItem().equals(DEFAULT)) {
            ssh.setPrefCSEncryption((String) jComboCipherCS.getSelectedItem());
        }
        if (!jComboCipherSC.getSelectedItem().equals(DEFAULT)) {
            ssh.setPrefSCEncryption((String) jComboCipherSC.getSelectedItem());
        }
        if (!jComboMacCS.getSelectedItem().equals(DEFAULT)) {
            ssh.setPrefCSMac((String) jComboMacCS.getSelectedItem());
        }
        if (!jComboMacSC.getSelectedItem().equals(DEFAULT)) {
            ssh.setPrefSCMac((String) jComboMacSC.getSelectedItem());
        }
        if (!jComboCompCS.getSelectedItem().equals(DEFAULT)) {
            ssh.setPrefCSComp((String) jComboCompCS.getSelectedItem());
        }
        if (!jComboCompSC.getSelectedItem().equals(DEFAULT)) {
            ssh.setPrefSCComp((String) jComboCompSC.getSelectedItem());
        }
        if (!jComboKex.getSelectedItem().equals(DEFAULT)) {
            ssh.setPrefKex((String) jComboKex.getSelectedItem());
        }
        if (!jComboPK.getSelectedItem().equals(DEFAULT)) {
            ssh.setPrefPublicKey((String) jComboPK.getSelectedItem());
        }

        // Return the connection properties
        return ssh;
    }


    /**
     *  Sets up the authentication method list
     */
    private void addAuthenticationMethods() {

        java.util.List methods = new ArrayList();

        methods.add(SHOW_AVAILABLE);
        methods.addAll(SshAuthenticationFactory.getSupportedMethods());
        jListAuths.setListData(methods.toArray());

    }


    /**
     *  Loads a list into a combo box
     *
     *@param  list        The source list
     *@param  combo       The destination combo box
     *@param  addDefault  Whether to add the <Default> item
     */
    private void loadList(java.util.List list, JComboBox combo, boolean addDefault) {

        Iterator it = list.iterator();

        if (addDefault) {
            combo.addItem(DEFAULT);
        }

        while (it.hasNext()) {
            combo.addItem(it.next());
        }

    }


    /**
     *  Called when the button has been pressed
     *
     *@param  e  The action
     */
    void jButtonConnect_actionPerformed(ActionEvent e) {

        // Validate that we have enough information
        if (jTextHostname.getText().equals("")
                || jTextPort.getText().equals("")
                || jTextUsername.getText().equals("")) {
            JOptionPane.showMessageDialog(this, "Please enter all details!", "Connect", JOptionPane.OK_OPTION);
            return;
        }

        // Determine whether any authenticaiton methods we selected
        Object[] auths = jListAuths.getSelectedValues();
        String a;
        if (auths != null) {

            for (int i = 0; i < auths.length; i++) {
                a = (String) auths[i];
                if (a.equals(SHOW_AVAILABLE)) {
                    hasChosenAuth = false;
                    break;
                } else {
                    hasChosenAuth = true;
                    methods.add(a);
                }

            }

        } else {
            hasChosenAuth = false;
        }

        // Hide the dialog
        this.hide();
    }


    /**
     *  Process a window event
     *
     *@param  e  The event
     */
    protected void processWindowEvent(WindowEvent e) {
        super.processWindowEvent(e);
        if (e.getID() == WindowEvent.WINDOW_CLOSING) {
            jTextPort.setText("-1");
            jTextHostname.setText("");
            jTextUsername.setText("");
            hide();
        }
    }

  /**
   * Handle the cancel event
   * @param e
   */
  void jButtonCancel_actionPerformed(ActionEvent e) {
      isCancelled = true;
      hide();
  }
}
