/*
* Copyright (c) 2002 Sshtools.com All rights reserved.
*
* Redistribution and use in source and binary forms, with or without modification,
* are permitted provided that the following conditions are met:
*
* Redistributions of source code must retain the above copyright notice, this list
* of conditions and the following disclaimer.
*
* Redistributions in binary form must reproduce the above copyright notice, this
* list of conditions and the following disclaimer in the documentation and/or other
* materials provided with the distribution.
*
* Neither the name of the Sshtools.com nor the names of its contributors may be
* used to endorse or promote products derived from this software without specific
* prior written permission.
*
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
* ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
* IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
* INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
* BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
* DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
* LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
* OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
* OF THE POSSIBILITY OF SUCH DAMAGE.
*
*/

package com.sshtools.sshterm;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.net.URL;
import javax.swing.AbstractAction;
import javax.swing.Action;
import javax.swing.ImageIcon;
import javax.swing.event.EventListenerList;

/**
 *  <p>
 *
 *  Extended Action class providing some useful methods.</p>
 *
 *@author     lee
 *@created    31 August 2002
 */
abstract class StandardAction extends AbstractAction {

    // The listener to action events (usually the main UI)
    private EventListenerList listeners;

    /**
     *  The imge directory path
     */
    public final static String IMAGE_DIR = "";

    /**
     *  The key used for storing a large icon for the action, used for toolbar
     *  buttons. <p>
     */
    public final static String LARGE_ICON = "LargeIcon";

    /**
     *  Gets the value from the key Action.ACTION_COMMAND_KEY
     *
     *@return    The actionCommand value
     */
    public String getActionCommand() {
        return (String) getValue(Action.ACTION_COMMAND_KEY);
    }

    /**
     *  Gets the value from the key Action.SHORT_DESCRIPTION
     *
     *@return    The shortDescription value
     */
    public String getShortDescription() {
        return (String) getValue(Action.SHORT_DESCRIPTION);
    }


    /**
     *  Gets the value from the key Action.LONG_DESCRIPTION
     *
     *@return    The longDescription value
     */
    public String getLongDescription() {
        return (String) getValue(Action.LONG_DESCRIPTION);
    }

    public String getName() {
      return (String) getValue(Action.NAME);
    }

    public String getSmallIcon() {
      return (String) getValue(Action.SMALL_ICON);
    }

    /**
     *  Forwards the ActionEvent to the registered listener.
     *
     *@param  evt  Description of the Parameter
     */
    public void actionPerformed(ActionEvent evt) {
        if (listeners != null) {
            Object[] listenerList = listeners.getListenerList();

            // Recreate the ActionEvent and stuff the value of the ACTION_COMMAND_KEY
            ActionEvent e = new ActionEvent(evt.getSource(), evt.getID(),
                    (String) getValue(Action.ACTION_COMMAND_KEY));
            for (int i = 0; i <= listenerList.length - 2; i += 2) {
                ((ActionListener) listenerList[i + 1]).actionPerformed(e);
            }
        }
    }

    /**
     *  Adds a feature to the ActionListener attribute of the StandardAction
     *  object
     *
     *@param  l  The feature to be added to the ActionListener attribute
     */
    public void addActionListener(ActionListener l) {
        if (listeners == null) {
            listeners = new EventListenerList();
        }
        listeners.add(ActionListener.class, l);
    }


    /**
     *  Description of the Method
     *
     *@param  l  Description of the Parameter
     */
    public void removeActionListener(ActionListener l) {
        if (listeners == null) {
            return;
        }
        listeners.remove(ActionListener.class, l);
    }


    /**
     *  Returns the Icon associated with the name from the resources. The
     *  resouce should be in the path.
     *
     *@param  name  Name of the icon file i.e., help16.gif
     *@return       the name of the image or null if the icon is not found.
     */
    public ImageIcon getIcon(String name) {
        String imagePath = IMAGE_DIR + name;
        URL url = this.getClass().getResource(imagePath);
        if (url != null) {
            return new ImageIcon(url);
        }
        return null;
    }
}
