/**
 * This source files within this package (com.sshtools.sshterm.emulation
 * have been derived from the The Java Telnet/SSH Applet source available
 * from www.javassh.org.
 *
 * This source is distributed under the GNU General Public License
 * a copy of which should have been provided with the distribution
 * you have received.
 */

package com.sshtools.sshterm.emulation;

import java.util.Properties;

/**
 *  An interface for a terminal that accepts input from keyboard and mouse.
 *
 *@author     Matthias L. Jugel, Marcus Meiner
 *@created    19 August 2002
 *@version    $Id: VDUInput.java,v 1.2 2002/09/16 20:02:17 martianx Exp $
 */

public interface VDUInput {

    /**
     *  Description of the Field
     */
    public final static int KEY_CONTROL = 0x01;
    /**
     *  Description of the Field
     */
    public final static int KEY_SHIFT = 0x02;
    /**
     *  Description of the Field
     */
    public final static int KEY_ALT = 0x04;
    /**
     *  Description of the Field
     */
    public final static int KEY_ACTION = 0x08;


    /**
     *  Direct access to writing data ...
     *
     *@param  b
     */
    void write(byte b[]);


    /**
     *  Terminal is mouse-aware and requires (x,y) coordinates of on the
     *  terminal (character coordinates) and the button clicked.
     *
     *@param  x
     *@param  y
     *@param  modifiers
     */
    void mousePressed(int x, int y, int modifiers);


    /**
     *  Terminal is mouse-aware and requires the coordinates and button of the
     *  release.
     *
     *@param  x
     *@param  y
     *@param  modifiers
     */
    void mouseReleased(int x, int y, int modifiers);


    /**
     *  Override the standard key codes used by the terminal emulation.
     *
     *@param  codes  a properties object containing key code definitions
     */
    void setKeyCodes(Properties codes);


    /**
     *  main keytyping event handler...
     *
     *@param  keyCode    the key code
     *@param  keyChar    the character represented by the key
     *@param  modifiers  shift/alt/control modifiers
     */
    void keyPressed(int keyCode, char keyChar, int modifiers);


    /**
     *  Handle key Typed events for the terminal, this will get all normal key
     *  types, but no shift/alt/control/numlock.
     *
     *@param  keyCode    the key code
     *@param  keyChar    the character represented by the key
     *@param  modifiers  shift/alt/control modifiers
     */
    void keyTyped(int keyCode, char keyChar, int modifiers);
}
