/*
* Copyright (c) 2002 Sshtools.com All rights reserved.
*
* Redistribution and use in source and binary forms, with or without modification,
* are permitted provided that the following conditions are met:
*
* Redistributions of source code must retain the above copyright notice, this list
* of conditions and the following disclaimer.
*
* Redistributions in binary form must reproduce the above copyright notice, this
* list of conditions and the following disclaimer in the documentation and/or other
* materials provided with the distribution.
*
* Neither the name of the Sshtools.com nor the names of its contributors may be
* used to endorse or promote products derived from this software without specific
* prior written permission.
*
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
* ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
* IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
* INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
* BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
* DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
* LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
* OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
* OF THE POSSIBILITY OF SUCH DAMAGE.
*
*/

package com.sshtools.util;

import javax.swing.JPanel;
import javax.swing.ImageIcon;
import com.borland.jbcl.layout.*;
import java.awt.*;
import java.net.URL;

/**
 * <p>A base panel for displaying images</p>
 *
 *@author     Lee David Painter (<A HREF="mailto:lee@sshtools.com">
 *      lee@sshtools.com</A> )
 *@created    31 August 2002
 *@version    1.0
 *
 */

public class ImagePanel extends JPanel {

    ResourceIcon icon;
    XYLayout xYLayout1 = new XYLayout();


    /**
     *  Constructor for the ImagePanel object
     *
     *@param  imageName  Description of the Parameter
     */
    public ImagePanel(String imageName) {

            icon = new ResourceIcon(imageName);

    }



    /**
     *  Paints the component
     *
     *@param  g  The graphics to paint to
     */
    public void paintComponent(Graphics g) {
        super.paintComponent(g);

        Insets insets = getInsets();

        icon.paintIcon(this, g, insets.left, insets.top);
    }


    /**
     *  Gets the preferedSize attribute of the ImagePanel object
     *
     *@return    The preferedSize value
     */
    public Dimension getPreferedSize() {
        Insets insets = getInsets();

        return new Dimension(icon.getIconWidth() + insets.left + insets.right,
                icon.getIconHeight() + insets.top + insets.bottom);
    }


    /**
     *  Constructor for the ImagePanel object
     */
    public ImagePanel() {
        try {
            jbInit();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }


    /**
     *  initiates the panel
     *
     *@exception  Exception
     */
    private void jbInit() throws Exception {
        this.setBackground(Color.white);
        this.setLayout(xYLayout1);
    }

}
