/*
* Copyright (c) 2002 Sshtools.com All rights reserved.
*
* Redistribution and use in source and binary forms, with or without modification,
* are permitted provided that the following conditions are met:
*
* Redistributions of source code must retain the above copyright notice, this list
* of conditions and the following disclaimer.
*
* Redistributions in binary form must reproduce the above copyright notice, this
* list of conditions and the following disclaimer in the documentation and/or other
* materials provided with the distribution.
*
* Neither the name of the Sshtools.com nor the names of its contributors may be
* used to endorse or promote products derived from this software without specific
* prior written permission.
*
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
* ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
* IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
* INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
* BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
* DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
* LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
* OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
* OF THE POSSIBILITY OF SUCH DAMAGE.
*
*/

package com.sshtools.util;

import javax.swing.ImageIcon;
import java.awt.Image;
import java.net.URL;
import java.awt.Toolkit;
import org.apache.log4j.Logger;

/**
 * <p>Loads an image from the resources</p>
 *
 *@author     Richard Pernavas (<A HREF="mailto:richard@sshtools.com">
 *      richard@sshtools.com</A> )
 *@created    31 August 2002
 *@version    1.0
 */

public class ResourceIcon extends ImageIcon
{

  private static Logger log = Logger.getLogger(ResourceIcon.class.getName());

  /**
   * Creates an ImageIcon from a resource image
   * @param imageName   The image filename
   */
  public ResourceIcon(String imageName)
  {
    super();
    Image image;
    URL url = this.getClass().getResource(imageName);

    if(url!=null) {

      log.debug(url.toString());
      image = Toolkit.getDefaultToolkit().getImage(url);
    }
    else
      image = Toolkit.getDefaultToolkit().getImage(imageName);

    this.setImage(image);
  }
}